@@ -41,16 +41,7 @@
 
 #include <glib-object.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkiconfactory.h>
+#include <gtk/gtk.h>
 
 #include "gedit-notebook.h"
 #include "gedit-marshal.h"
