@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin.h 6493 2008-09-06 14:51:52Z jessevdk $
+ * $Id: gedit-plugin.h 6635 2008-11-29 20:57:47Z pborelli $
  */
 
 #ifndef __GEDIT_PLUGIN_H__
@@ -117,56 +117,28 @@ GtkWidget	*gedit_plugin_create_configure_dialog
  *
  * Utility macro used to register plugins with additional code.
  */
-#define GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, CODE)	\
+#define GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE(PluginName, plugin_name, CODE) 	\
+	G_DEFINE_DYNAMIC_TYPE_EXTENDED (PluginName,				\
+					plugin_name,				\
+					GEDIT_TYPE_PLUGIN,			\
+					0,					\
+					GTypeModule *module G_GNUC_UNUSED = type_module; /* back compat */	\
+					CODE)					\
 										\
-static GType plugin_name##_type = 0;						\
-										\
-GType										\
-plugin_name##_get_type (void)							\
+/* This is not very nice, but G_DEFINE_DYNAMIC wants it and our old macro	\
+ * did not support it */							\
+static void									\
+plugin_name##_class_finalize (PluginName##Class *klass)				\
 {										\
-	return plugin_name##_type;						\
 }										\
 										\
-static void     plugin_name##_init              (PluginName        *self);	\
-static void     plugin_name##_class_init        (PluginName##Class *klass);	\
-static gpointer plugin_name##_parent_class = NULL;				\
-static void     plugin_name##_class_intern_init (gpointer klass)		\
-{										\
-	plugin_name##_parent_class = g_type_class_peek_parent (klass);		\
-	plugin_name##_class_init ((PluginName##Class *) klass);			\
-}										\
 										\
 G_MODULE_EXPORT GType								\
-register_gedit_plugin (GTypeModule *module)					\
+register_gedit_plugin (GTypeModule *type_module)				\
 {										\
-	static const GTypeInfo our_info =					\
-	{									\
-		sizeof (PluginName##Class),					\
-		NULL, /* base_init */						\
-		NULL, /* base_finalize */					\
-		(GClassInitFunc) plugin_name##_class_intern_init,		\
-		NULL,								\
-		NULL, /* class_data */						\
-		sizeof (PluginName),						\
-		0, /* n_preallocs */						\
-		(GInstanceInitFunc) plugin_name##_init				\
-	};									\
+	plugin_name##_register_type (type_module);				\
 										\
-	gedit_debug_message (DEBUG_PLUGINS, "Registering " #PluginName);	\
-										\
-	/* Initialise the i18n stuff */						\
-	bindtextdomain (GETTEXT_PACKAGE, GEDIT_LOCALEDIR);			\
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");			\
-										\
-	plugin_name##_type = g_type_module_register_type (module,		\
-					    GEDIT_TYPE_PLUGIN,			\
-					    #PluginName,			\
-					    &our_info,				\
-					    0);					\
-										\
-	CODE									\
-										\
-	return plugin_name##_type;						\
+	return plugin_name##_get_type();					\
 }
 
 /**
@@ -181,8 +153,10 @@ register_gedit_plugin (GTypeModule *module)					\
  * GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE):
  *
  * Utility macro used to register gobject types in plugins with additional code.
+ *
+ * Deprecated: use G_DEFINE_DYNAMIC_TYPE_EXTENDED instead
  */
-#define GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE)	\
+#define GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, CODE) \
 										\
 static GType g_define_type_id = 0;						\
 										\
@@ -202,8 +176,9 @@ static void     object_name##_class_intern_init (gpointer klass)		\
 }										\
 										\
 GType										\
-object_name##_register_type (GTypeModule *module)					\
+object_name##_register_type (GTypeModule *type_module)				\
 {										\
+	GTypeModule *module G_GNUC_UNUSED = type_module; /* back compat */			\
 	static const GTypeInfo our_info =					\
 	{									\
 		sizeof (ObjectName##Class),					\
@@ -217,9 +192,7 @@ object_name##_register_type (GTypeModule *module)					\
 		(GInstanceInitFunc) object_name##_init				\
 	};									\
 										\
-	gedit_debug_message (DEBUG_PLUGINS, "Registering " #ObjectName);	\
-										\
-	g_define_type_id = g_type_module_register_type (module,			\
+	g_define_type_id = g_type_module_register_type (type_module,		\
 					   	        PARENT_TYPE,		\
 					                #ObjectName,		\
 					                &our_info,		\
@@ -230,10 +203,13 @@ object_name##_register_type (GTypeModule *module)					\
 	return g_define_type_id;						\
 }
 
+
 /**
  * GEDIT_PLUGIN_DEFINE_TYPE(ObjectName, object_name, PARENT_TYPE):
  *
  * Utility macro used to register gobject types in plugins.
+ *
+ * Deprecated: use G_DEFINE_DYNAMIC instead
  */
 #define GEDIT_PLUGIN_DEFINE_TYPE(ObjectName, object_name, PARENT_TYPE)		\
 	GEDIT_PLUGIN_DEFINE_TYPE_WITH_CODE(ObjectName, object_name, PARENT_TYPE, ;)
@@ -251,13 +227,11 @@ object_name##_register_type (GTypeModule *module)					\
 		NULL								\
 	};									\
 										\
-	g_type_module_add_interface (module, 					\
+	g_type_module_add_interface (type_module, 					\
 				     g_define_type_id, 				\
 				     TYPE_IFACE, 				\
-				     &object_name##_interface_info);		\
+				     &object_name##_interface_info);
 
 G_END_DECLS
 
 #endif  /* __GEDIT_PLUGIN_H__ */
-
-
