@@ -32,7 +32,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-spinner.c 5353 2006-12-09 19:47:18Z pborelli $
+ * $Id: gedit-spinner.c 6631 2008-11-29 11:06:49Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,9 +42,7 @@
 #include "gedit-spinner.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtksettings.h>
+#include <gtk/gtk.h>
 
 /* Spinner cache implementation */
 
