@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c 6379 2008-08-10 16:40:21Z pborelli $
+ * $Id: gedit-utils.c 6631 2008-11-29 11:06:49Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +41,7 @@
 #include <fcntl.h>
 #include <string.h>
 
-#include <glib/gunicode.h>
+#include <glib.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
@@ -549,10 +549,10 @@ gedit_warning (GtkWindow *parent, const gchar *format, ...)
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		   	GTK_MESSAGE_ERROR,
 		   	GTK_BUTTONS_OK,
-			str);
+			"%s", str);
 
 	g_free (str);
-	
+
 	if (wg != NULL)
 		gtk_window_group_add_window (wg, GTK_WINDOW (dialog));
 		
@@ -1264,13 +1264,6 @@ gedit_utils_basename_for_display (gchar const *uri)
  * Filter, modify, unescape and change @uri to make it appropriate
  * for display to users.
  * 
- * Rules:
- * <ul>
- * <li>file: uri without fragments should appear as local paths.</li>
- * <li>file: uri with fragments should appear as file:uri.</li>
- * <li>All other uri appear as expected.</li>
- * </ul>
- *
  * This function is a convenient wrapper for g_file_get_parse_name
  *
  * Return value: a string which represents @uri and can be displayed.
@@ -1280,16 +1273,12 @@ gedit_utils_uri_for_display (const gchar *uri)
 {
 	GFile *gfile;
 	gchar *parse_name;
-	gchar *unescape;
-	
+
 	gfile = g_file_new_for_uri (uri);
-	
 	parse_name = g_file_get_parse_name (gfile);
-	unescape = g_uri_unescape_string (parse_name, NULL);
-	g_free (parse_name);
-	
 	g_object_unref (gfile);
-	return unescape;
+
+	return parse_name;
 }
 
 /**
