@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-spell-plugin.c 5880 2007-09-05 18:39:38Z jwendell $
+ * $Id: gedit-spell-plugin.c 6643 2008-12-01 10:25:59Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,8 +32,6 @@
 #include <glib/gutils.h>
 #include <gmodule.h>
 
-#include <libgnomeui/gnome-stock-icons.h>
-
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-metadata-manager.h>
 #include <gedit/gedit-prefs-manager.h>
@@ -47,7 +45,9 @@
 #define WINDOW_DATA_KEY "GeditSpellPluginWindowData"
 #define MENU_PATH "/MenuBar/ToolsMenu/ToolsOps_1"
 
-#define GEDIT_SPELL_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_SPELL_PLUGIN, GeditSpellPluginPrivate))
+#define GEDIT_SPELL_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+					       GEDIT_TYPE_SPELL_PLUGIN, \
+					       GeditSpellPluginPrivate))
 
 GEDIT_PLUGIN_REGISTER_TYPE(GeditSpellPlugin, gedit_spell_plugin)
 
@@ -74,7 +74,7 @@ static const GtkActionEntry action_entries[] =
 	},
 
 	{ "ConfigSpell",
-	  GNOME_STOCK_BOOK_BLUE,
+	  NULL,
 	  N_("Set _Language..."),
 	  NULL,
 	  N_("Set the language of the current document"),
@@ -996,8 +996,8 @@ gedit_spell_plugin_class_init (GeditSpellPluginClass *klass)
 	plugin_class->update_ui = impl_update_ui;
 
 	if (spell_checker_id == 0)
-		spell_checker_id = g_quark_from_static_string ("GeditSpellCheckerID");
-	
+		spell_checker_id = g_quark_from_string ("GeditSpellCheckerID");
+
 	if (check_range_id == 0)
-		check_range_id = g_quark_from_static_string ("CheckRangeID");
+		check_range_id = g_quark_from_string ("CheckRangeID");
 }
